Terminology
###########

#. *Project* - a directory tree that contains everything related to one project.
#. *Aspect* - an aspect of a project, eg. browser or mailer.
#. *Category* - a name that groups patterns of similar complexity, eg. atoms.
#. *Pattern* - a visual component that can be rendered in isolation.
#. *Variation* - a pattern that is so similar to an existing pattern that it does not warrant to be a pattern itself.
#. *Explorer* - a web browsable interface of all the projects visible to Mote.
#. *Mote Templating Language* - simple Jinja based markup language for writing patterns.
#. *Deep merging* - the algorithm used to merge dynamic data into a pattern's source data.
